from nf_common_base.b_source.common.configurations.b_configurations.b_configurations import (
    BConfigurations,
)


# TODO: should this became an object??
class BClearerConfigurations(
    BConfigurations
):
    pass
